==> kubernetes-model-apiextensions-4.12.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceDefinitionNamesBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class CustomResourceDefinitionNamesBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesBuilder> implements VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesBuilder> {

    io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesFluent<?> fluent;
    Boolean validationEnabled;

    public CustomResourceDefinitionNamesBuilder() { 
        this(true);
    }


    public CustomResourceDefinitionNamesBuilder(Boolean validationEnabled) { 
        this(new CustomResourceDefinitionNames(), validationEnabled);
    }


    public CustomResourceDefinitionNamesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesFluent<?> fluent) { 
        this(fluent, true);
    }


    public CustomResourceDefinitionNamesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new CustomResourceDefinitionNames(), validationEnabled);
    }


    public CustomResourceDefinitionNamesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames instance) { 
        this(fluent, instance, true);
    }


    public CustomResourceDefinitionNamesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withCategories(instance.getCategories()); 
        fluent.withKind(instance.getKind()); 
        fluent.withListKind(instance.getListKind()); 
        fluent.withPlural(instance.getPlural()); 
        fluent.withShortNames(instance.getShortNames()); 
        fluent.withSingular(instance.getSingular()); 
        this.validationEnabled = validationEnabled; 
    }


    public CustomResourceDefinitionNamesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames instance) { 
        this(instance,true);
    }


    public CustomResourceDefinitionNamesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withCategories(instance.getCategories()); 
        this.withKind(instance.getKind()); 
        this.withListKind(instance.getListKind()); 
        this.withPlural(instance.getPlural()); 
        this.withShortNames(instance.getShortNames()); 
        this.withSingular(instance.getSingular()); 
        this.validationEnabled = validationEnabled; 
    }


    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames build() {
        CustomResourceDefinitionNames buildable = new CustomResourceDefinitionNames(fluent.getCategories(),fluent.getKind(),fluent.getListKind(),fluent.getPlural(),fluent.getShortNames(),fluent.getSingular());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        CustomResourceDefinitionNamesBuilder that = (CustomResourceDefinitionNamesBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-apiextensions-5.7.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceDefinitionNamesBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class CustomResourceDefinitionNamesBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesBuilder> {

    io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesFluent<?> fluent;
    java.lang.Boolean validationEnabled;

    public CustomResourceDefinitionNamesBuilder() {
        this(true);
    }

    public CustomResourceDefinitionNamesBuilder(java.lang.Boolean validationEnabled) {
        this(new CustomResourceDefinitionNames(), validationEnabled);
    }

    public CustomResourceDefinitionNamesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesFluent<?> fluent) {
        this(fluent, true);
    }

    public CustomResourceDefinitionNamesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesFluent<?> fluent,java.lang.Boolean validationEnabled) {
        this(fluent, new CustomResourceDefinitionNames(), validationEnabled);
    }

    public CustomResourceDefinitionNamesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames instance) {
        this(fluent, instance, true);
    }

    public CustomResourceDefinitionNamesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames instance,java.lang.Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withCategories(instance.getCategories()); 
        fluent.withKind(instance.getKind()); 
        fluent.withListKind(instance.getListKind()); 
        fluent.withPlural(instance.getPlural()); 
        fluent.withShortNames(instance.getShortNames()); 
        fluent.withSingular(instance.getSingular()); 
        this.validationEnabled = validationEnabled; 
    }

    public CustomResourceDefinitionNamesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames instance) {
        this(instance,true);
    }

    public CustomResourceDefinitionNamesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames instance,java.lang.Boolean validationEnabled) {
        this.fluent = this; 
        this.withCategories(instance.getCategories()); 
        this.withKind(instance.getKind()); 
        this.withListKind(instance.getListKind()); 
        this.withPlural(instance.getPlural()); 
        this.withShortNames(instance.getShortNames()); 
        this.withSingular(instance.getSingular()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames build() {
        CustomResourceDefinitionNames buildable = new CustomResourceDefinitionNames(fluent.getCategories(),fluent.getKind(),fluent.getListKind(),fluent.getPlural(),fluent.getShortNames(),fluent.getSingular());
        return buildable;
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        CustomResourceDefinitionNamesBuilder that = (CustomResourceDefinitionNamesBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
